==> org-lsst-ccs-subsystem-commons-buses-6.9.9-sources.jar: org/lsst/ccs/subsystem/common/actions/RefrigAction.java <==
package org.lsst.ccs.subsystem.common.actions;

import java.io.Serializable;
import org.lsst.ccs.bus.data.Alert;

/**
 *  Manages the refrig alert action payload
 * 
 *  @author saxton
 */
public class RefrigAction implements Serializable {

    public enum Action { COLD_PLATE_TOO_COLD, CRYO_PLATE_TOO_COLD, CRYO_CIRCUIT_TOO_COLD, VACUUM_INSUFFICIENT }

    public Action action;    // The action to perform
    public String compName;  // The compressor name, or empty string if not applicable

    /**
     *  Constructor.
     * 
     *  @param action  The action to perform
     *  @param compName  The compressor name
     */
    public RefrigAction(Action action, String compName)
    {
        this.action = action;
        this.compName = compName;
    }

    /**
     *  Gets the simple name of this class.
     * 
     *  @return  The name
     */
    public static String getName()
    {
        return RefrigAction.class.getSimpleName();
    }

    /**
     *  Gets the name of the client property.
     * 
     *  @return  The name
     */
    public static String getClientName()
    {
        return getName() + "Client";
    }

    /**
     *  Gets the name of the manager property.
     * 
     *  @return  The name
     */
    public static String getManagerName()
    {
        return getName() + "Manager";
    }

    /**
     *  Adds data to an alert
     * 
     *  @param  alert  The alert
     *  @param  action  The action to perform
     *  @param  compName  The affected compressor name, or empty string if not applicable
     */
    public static void addData(Alert alert, Action action, String compName)
    {
        alert.addAlertData(getName(), new RefrigAction(action, compName));
    }

    /**
     *  Adds data to an alert
     * 
     *  @param  alert  The alert
     *  @param  action  The action to perform
     */
    public static void addData(Alert alert, Action action)
    {
        addData(alert, action, "");
    }

    /**
     *  Gets data from an alert.
     * 
     *  @param  alert  The alert
     *  @return  The action, or null if the alert doesn't contain RefrigAction payload
     */
    public static RefrigAction getData(Alert alert)
    {
        Object data = alert.getAlertData(getName());
        return data instanceof RefrigAction ? (RefrigAction)data : null;
    }

    private static final long serialVersionUID = 5064456225867172135L;
}

==> org-lsst-ccs-subsystem-commons-buses-6.9.30-sources.jar: org/lsst/ccs/subsystem/common/actions/RefrigAction.java <==
package org.lsst.ccs.subsystem.common.actions;

import java.io.Serializable;
import org.lsst.ccs.bus.data.Alert;

/**
 *  Manages the refrig alert action payload
 * 
 *  @author saxton
 */
public class RefrigAction implements Serializable {

    public enum Action { COLD_PLATE_TOO_COLD, COLD_PLATE_TOO_WARM, CRYO_PLATE_TOO_COLD, CRYO_CIRCUIT_TOO_COLD, VACUUM_INSUFFICIENT }

    public Action action;    // The action to perform
    public String compName;  // The compressor name, or empty string if not applicable

    /**
     *  Constructor.
     * 
     *  @param action  The action to perform
     *  @param compName  The compressor name
     */
    public RefrigAction(Action action, String compName)
    {
        this.action = action;
        this.compName = compName;
    }

    /**
     *  Gets the simple name of this class.
     * 
     *  @return  The name
     */
    public static String getName()
    {
        return RefrigAction.class.getSimpleName();
    }

    /**
     *  Gets the name of the client property.
     * 
     *  @return  The name
     */
    public static String getClientName()
    {
        return getName() + "Client";
    }

    /**
     *  Gets the name of the manager property.
     * 
     *  @return  The name
     */
    public static String getManagerName()
    {
        return getName() + "Manager";
    }

    /**
     *  Adds data to an alert
     * 
     *  @param  alert  The alert
     *  @param  action  The action to perform
     *  @param  compName  The affected compressor name, or empty string if not applicable
     */
    public static void addData(Alert alert, Action action, String compName)
    {
        alert.addAlertData(getName(), new RefrigAction(action, compName));
    }

    /**
     *  Adds data to an alert
     * 
     *  @param  alert  The alert
     *  @param  action  The action to perform
     */
    public static void addData(Alert alert, Action action)
    {
        addData(alert, action, "");
    }

    /**
     *  Gets data from an alert.
     * 
     *  @param  alert  The alert
     *  @return  The action, or null if the alert doesn't contain RefrigAction payload
     */
    public static RefrigAction getData(Alert alert)
    {
        Object data = alert.getAlertData(getName());
        return data instanceof RefrigAction ? (RefrigAction)data : null;
    }

    private static final long serialVersionUID = 5064456225867172135L;
}
